@@ -2,7 +2,7 @@
 /*
     This file is part of MARX
 
-    Copyright (C) 2002-2015 Massachusetts Institute of Technology
+    Copyright (C) 2002-2016 Massachusetts Institute of Technology
 
     This software was developed by the MIT Center for Space Research
     under contract SV1-61010 from the Smithsonian Institution.
@@ -26,8 +26,8 @@
 #include <jdmath.h>
 #include <pfile.h>
 
-#define MARX_VERSION 50200
-#define MARX_VERSION_STRING "5.2.0"
+#define MARX_VERSION 50300
+#define MARX_VERSION_STRING "5.3.0"
 
 #ifndef SIGNED_CHAR
 # define SIGNED_CHAR signed char
@@ -587,4 +587,10 @@ extern Marx_Subpix_Table_Type *marx_open_acis_subpix (void);
 extern void marx_close_acis_subpixel (Marx_Subpix_Table_Type *);
 extern int marx_compute_acis_subpix (Marx_Subpix_Table_Type *stt,
 			      int ccd, float energy, int fltgrade, float *dxp, float *dyp);
+
+/* This function computes the azimuth and elevation of the source with
+ * respect to the spacecraft pointing axis, which is generally different
+ * from the optical axis.
+ */
+extern int marx_compute_elaz (double Ra, double Dec, double *azp, double *elp);
 #endif				       /* _MARX_H_ */
